# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ComputerTypeTextParams"]


class ComputerTypeTextParams(TypedDict, total=False):
    tab_id: str

    text: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ComputerSetViewportParams"]


class ComputerSetViewportParams(TypedDict, total=False):
    height: int

    scale_factor: float

    tab_id: str

    width: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ComputerCreateParams", "Display"]


class ComputerCreateParams(TypedDict, total=False):
    auto_kill: bool
    """If true (default), kill session after inactivity.

    If false, only kill on explicit stop or max_lifetime
    """

    context_id: str

    display: Display
    """TODO: implement"""

    kind: str
    """\"browser"|"desktop"|"code" etc"""

    stealth: object
    """TODO: implement"""

    timeout_seconds: int


class Display(TypedDict, total=False):
    height: int

    scale: float

    width: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .action_result import ActionResult as ActionResult
from .computer_response import ComputerResponse as ComputerResponse
from .computer_drag_params import ComputerDragParams as ComputerDragParams
from .computer_click_params import ComputerClickParams as ComputerClickParams
from .computer_debug_params import ComputerDebugParams as ComputerDebugParams
from .computer_create_params import ComputerCreateParams as ComputerCreateParams
from .computer_list_response import ComputerListResponse as ComputerListResponse
from .computer_get_html_params import ComputerGetHTMLParams as ComputerGetHTMLParams
from .computer_navigate_params import ComputerNavigateParams as ComputerNavigateParams
from .computer_type_text_params import ComputerTypeTextParams as ComputerTypeTextParams
from .computer_right_click_params import ComputerRightClickParams as ComputerRightClickParams
from .computer_double_click_params import ComputerDoubleClickParams as ComputerDoubleClickParams
from .computer_keep_alive_response import ComputerKeepAliveResponse as ComputerKeepAliveResponse
from .computer_press_hotkey_params import ComputerPressHotkeyParams as ComputerPressHotkeyParams
from .computer_set_viewport_params import ComputerSetViewportParams as ComputerSetViewportParams
from .computer_execute_batch_params import ComputerExecuteBatchParams as ComputerExecuteBatchParams
from .computer_execute_action_params import ComputerExecuteActionParams as ComputerExecuteActionParams
from .computer_execute_batch_response import ComputerExecuteBatchResponse as ComputerExecuteBatchResponse
from .computer_scroll_viewport_params import ComputerScrollViewportParams as ComputerScrollViewportParams
from .computer_capture_screenshot_params import ComputerCaptureScreenshotParams as ComputerCaptureScreenshotParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .computer_response import ComputerResponse

__all__ = ["ComputerListResponse"]

ComputerListResponse: TypeAlias = List[ComputerResponse]



"""Custom library extensions - safe from Stainless regeneration."""

from .wrapper import ComputerSession
from .result_types import (
    ScreenshotResult,
    HTMLResult,
    DebugResult,
    get_screenshot_url,
    get_html_content,
    get_debug_response,
)

__all__ = [
    "ComputerSession",
    "ScreenshotResult",
    "HTMLResult",
    "DebugResult",
    "get_screenshot_url",
    "get_html_content",
    "get_debug_response",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import TypedDict

from .._types import SequenceNotStr

__all__ = ["ComputerExecuteBatchParams", "Action", "ActionDebug"]


class ComputerExecuteBatchParams(TypedDict, total=False):
    actions: Iterable[Action]


class ActionDebug(TypedDict, total=False):
    command: str

    max_output_length: int

    timeout_seconds: int


class Action(TypedDict, total=False):
    auto_detect_encoding: bool
    """For get_html_content"""

    base64: bool
    """For screenshot"""

    button: str

    debug: ActionDebug

    dx: float
    """For scrolling"""

    dy: float

    height: int

    include_context: bool
    """Include page context in response"""

    keys: SequenceNotStr[str]

    ms: int

    scale_factor: float

    tab_id: str
    """For tab management (browser sessions only)"""

    text: str

    type: str
    """
    click|double_click|right_click|drag|type|keypress|scroll|wait|screenshot|go_to_url|debug|get_html_content|set_viewport|list_tabs|new_tab|switch_tab|close_tab
    """

    url: str

    width: int
    """For set_viewport"""

    x: float

    x1: float
    """For dragging/scrolling"""

    x2: float
    """For dragging"""

    y: float

    y1: float

    y2: float
